import React, { useRef, useEffect, useLayoutEffect, useState } from 'react';
import PropTypes from 'prop-types';
import 'helix-ui';

/**
 * @see https://laptrinhx.com/reusing-the-ref-from-forwardref-with-react-hooks-3215655428/
 * @param refs
 * @return {React.MutableRefObject}
 */

function useCombinedRefs(...refs) {
  const targetRef = React.useRef();
  React.useEffect(() => {
    refs.forEach(ref => {
      if (!ref) return;

      if (typeof ref === 'function') {
        ref(targetRef.current);
      } else {
        ref.current = targetRef.current;
      }
    });
  }, [refs]);
  return targetRef;
}

const handlerNameToEvent = handlerName => handlerName.replace(/^on/, '').toLowerCase();
/**
 * Adds event handlers like onOpen or onClose to event listeners: 'open' or 'close'
 * @param {object} eventHandlers such as onClose, onOpen, ...etc
 * @param {React.MutableRefObject} ref
 * @return {React.MutableRefObject}
 */


function useEventListener(eventHandlers = {}, ref) {
  const theRef = ref ? useCombinedRefs(ref, useRef(null)) : useRef(null);
  useEffect(() => {
    Object.entries(eventHandlers).forEach(([handlerName, eventHandler]) => {
      theRef.current.addEventListener(handlerNameToEvent(handlerName), eventHandler);
    });
    return () => {
      Object.entries(eventHandlers).forEach(([handlerName, eventHandler]) => {
        theRef.current.removeEventListener(handlerNameToEvent(handlerName), eventHandler);
      });
    };
  }, []);
  return theRef;
}

const Alert = /*#__PURE__*/React.forwardRef(({
  onOpen,
  onClose,
  className,
  children,
  onDismiss,
  onSubmit,
  ...rest
}, ref) => {
  const hxRef = useEventListener({
    onDismiss,
    onSubmit
  }, ref);
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("hx-alert", Object.assign({
    class: className,
    ref: hxRef
  }, rest), children));
});
Alert.displayName = 'Alert';
Alert.propTypes = {
  className: PropTypes.string,
  children: PropTypes.node.isRequired,
  type: PropTypes.string,
  status: PropTypes.string,
  cta: PropTypes.string,
  persist: PropTypes.bool,
  onDismiss: PropTypes.func,
  onSubmit: PropTypes.func
};

const Icon = ({
  type,
  className,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-icon", Object.assign({
    type: type
  }, rest, {
    class: className
  }));
};

Icon.propTypes = {
  type: PropTypes.string,
  className: PropTypes.string
};

const Busy = ({
  className,
  children,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-busy", Object.assign({
    class: className
  }, rest));
};

Busy.propTypes = {
  paused: PropTypes.bool,
  className: PropTypes.string
};

function cssFor(modifier) {
  return {
    large: 'hxLg',
    primary: 'hxPrimary',
    small: 'hxSm',
    tertiary: 'hxTertiary'
  }[modifier];
}

function classNames(props) {
  return ['hxBtn', cssFor(props.variant), cssFor(props.size), props.className].join(' ').trim();
}

class Button extends React.Component {
  render() {
    // destructure props for JSX composition
    const {
      busy,
      children,
      // explicity placed
      className,
      // removed to prevent duplicate prop
      headIcon,
      size,
      tailIcon,
      type,
      variant,
      ...props
    } = this.props;
    return /*#__PURE__*/React.createElement("button", Object.assign({
      className: classNames(this.props),
      type: type || 'button'
    }, props), headIcon && /*#__PURE__*/React.createElement(Icon, {
      type: headIcon
    }), children && /*#__PURE__*/React.createElement("span", null, children), busy ? /*#__PURE__*/React.createElement(Busy, null) : tailIcon && /*#__PURE__*/React.createElement(Icon, {
      type: tailIcon
    }));
  }

}

Button.propTypes = {
  busy: PropTypes.bool,
  disabled: PropTypes.bool,
  headIcon: PropTypes.string,
  size: PropTypes.string,
  tailIcon: PropTypes.string,
  type: PropTypes.string,
  variant: PropTypes.string
};

const Breadcrumb = ({
  children,
  icon: _icon = 'angle-right',
  addDelimiter: _addDelimiter = true,
  ...rest
}) => {
  // Automatically add delimiter
  const kids = children.length > 0 ? children.map((child, index) => [child, _addDelimiter && index + 1 < children.length && /*#__PURE__*/React.createElement("hx-icon", {
    key: index,
    class: "delimiter",
    type: _icon
  })]) : children;
  return /*#__PURE__*/React.createElement("nav", Object.assign({
    className: "hxBreadcrumb"
  }, rest), kids);
};

Breadcrumb.propTypes = {
  icon: PropTypes.string,
  children: PropTypes.node
};

const Checkbox = /*#__PURE__*/React.forwardRef(({
  id,
  label,
  indeterminate,
  className,
  style,
  ...rest
}, ref) => {
  const hxRef = useCombinedRefs(ref, useRef());
  useEffect(() => {
    hxRef.current.indeterminate = indeterminate;
  }, [indeterminate]);
  return /*#__PURE__*/React.createElement("hx-checkbox-control", {
    class: className
  }, /*#__PURE__*/React.createElement("input", Object.assign({
    ref: hxRef
  }, rest, {
    id: id,
    type: "checkbox"
  })), /*#__PURE__*/React.createElement("label", {
    htmlFor: id
  }, /*#__PURE__*/React.createElement("hx-checkbox", null), label));
});
Checkbox.displayName = 'Checkbox';
Checkbox.propTypes = {
  className: PropTypes.string,
  style: PropTypes.object,
  checked: PropTypes.bool,
  id: PropTypes.string.isRequired,
  disabled: PropTypes.bool,
  indeterminate: PropTypes.bool,
  required: PropTypes.bool,
  label: PropTypes.string,
  name: PropTypes.string,
  onChange: PropTypes.func
};

function createCommonjsModule(fn, basedir, module) {
	return module = {
	  path: basedir,
	  exports: {},
	  require: function (path, base) {
      return commonjsRequire();
    }
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var classnames = createCommonjsModule(function (module) {
/*!
  Copyright (c) 2017 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/
/* global define */

(function () {

	var hasOwn = {}.hasOwnProperty;

	function classNames () {
		var classes = [];

		for (var i = 0; i < arguments.length; i++) {
			var arg = arguments[i];
			if (!arg) continue;

			var argType = typeof arg;

			if (argType === 'string' || argType === 'number') {
				classes.push(arg);
			} else if (Array.isArray(arg) && arg.length) {
				var inner = classNames.apply(null, arg);
				if (inner) {
					classes.push(inner);
				}
			} else if (argType === 'object') {
				for (var key in arg) {
					if (hasOwn.call(arg, key) && arg[key]) {
						classes.push(key);
					}
				}
			}
		}

		return classes.join(' ');
	}

	if ( module.exports) {
		classNames.default = classNames;
		module.exports = classNames;
	} else {
		window.classNames = classNames;
	}
}());
});

const SIZES = {
  small: 'hxSm',
  medium: 'hxMd',
  large: 'hxLg'
};
const POSITIONS = ['top-left', 'top-center', 'top-right', 'right-top', 'right-middle', 'right-bottom', 'bottom-right', 'bottom-center', 'bottom-left', 'left-bottom', 'left-middle', 'left-top'];

/**
 * Because Web components attributes convert booleans to strings
 * this stops values like false from being converted to "false" and then evaluating as true.
 * @param {boolean} bool
 * @return {*}
 */
const wcBool = bool => bool ? true : null;

const ChoiceTile = ({
  checked,
  children,
  className,
  disabled,
  icon,
  invalid,
  name,
  onChange,
  size,
  subdued,
  title,
  style,
  radioInput,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("label", {
    className: classnames({
      hxChoice: true
    }, className),
    style: style
  }, radioInput ? radioInput : /*#__PURE__*/React.createElement("input", Object.assign({
    checked: wcBool(checked),
    disabled: disabled,
    invalid: invalid?.toString(),
    name: name,
    onChange: onChange,
    type: "radio"
  }, rest)), /*#__PURE__*/React.createElement("hx-tile", {
    class: classnames({
      hxSubdued: subdued,
      [SIZES[size]]: true
    })
  }, /*#__PURE__*/React.createElement("hx-icon", {
    type: "checkmark"
  }), icon && /*#__PURE__*/React.createElement("div", {
    className: "hx-tile-icon"
  }, /*#__PURE__*/React.createElement("hx-icon", {
    type: icon
  })), /*#__PURE__*/React.createElement("header", null, title), children));
};

ChoiceTile.propTypes = {
  checked: PropTypes.bool.isRequired,
  children: PropTypes.node,
  className: PropTypes.string,
  style: PropTypes.object,
  disabled: PropTypes.bool,
  icon: PropTypes.string,
  invalid: PropTypes.bool,
  name: PropTypes.string,
  onChange: PropTypes.func,
  size: PropTypes.oneOf(Object.keys(SIZES)),
  subdued: PropTypes.bool,
  title: PropTypes.string.isRequired,
  radioInput: PropTypes.node
};
ChoiceTile.defaultProps = {
  checked: false,
  size: 'medium'
};

const Disclosure = /*#__PURE__*/React.forwardRef(({
  className,
  ariaControls,
  ariaExpanded,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement("hx-disclosure", Object.assign({
    ref: ref,
    class: className,
    "aria-controls": ariaControls,
    "aria-expanded": wcBool(ariaExpanded)
  }, rest));
});
Disclosure.propTypes = {
  ariaControls: PropTypes.string.isRequired,
  ariaExpanded: PropTypes.bool,
  role: PropTypes.string,
  tabindex: PropTypes.string,
  className: PropTypes.string,
  children: PropTypes.node.isRequired
};
Disclosure.displayName = 'Disclosure';

const Div = ({
  className,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-div", Object.assign({
    class: className
  }, rest));
};

Div.propTypes = {
  className: PropTypes.string,
  children: PropTypes.node.isRequired,
  scroll: PropTypes.oneOf(['vertical', 'horizontal', 'both', 'none'])
};

const Drawer = /*#__PURE__*/React.forwardRef(({
  children,
  className,
  id,
  onClose,
  onOpen,
  open,
  size,
  ...rest
}, ref) => {
  const hxRef = useEventListener({
    onOpen,
    onClose
  }, ref);
  return /*#__PURE__*/React.createElement("hx-drawer", Object.assign({
    class: classnames(className, SIZES[size]),
    id: id,
    open: wcBool(open),
    ref: hxRef
  }, rest), children);
});
Drawer.displayName = 'Drawer';
Drawer.propTypes = {
  className: PropTypes.string,
  id: PropTypes.string.isRequired,
  onClose: PropTypes.func,
  onOpen: PropTypes.func,
  open: PropTypes.bool,
  size: PropTypes.oneOf(Object.keys(SIZES))
};
Drawer.defaultProps = {
  open: null
};

const Modal = /*#__PURE__*/React.forwardRef(({
  onOpen,
  onClose,
  className,
  open,
  size,
  children,
  ...rest
}, ref) => {
  const hxRef = useEventListener({
    onOpen,
    onClose
  }, ref);
  return /*#__PURE__*/React.createElement("hx-modal", Object.assign({
    class: classnames(className, SIZES[size]),
    ref: hxRef,
    open: wcBool(open)
  }, rest), children);
});
Modal.displayName = 'Modal';
Modal.propTypes = {
  id: PropTypes.string,
  size: PropTypes.oneOf(Object.keys(SIZES)),
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  open: PropTypes.bool,
  onClose: PropTypes.func,
  onOpen: PropTypes.func
};

const Pill = ({
  className,
  children,
  onDismiss,
  ...rest
}) => {
  const hxRef = useEventListener({
    onDismiss
  });
  return /*#__PURE__*/React.createElement("hx-pill", Object.assign({
    class: className
  }, rest, {
    ref: hxRef
  }), children);
};

Pill.propTypes = {
  persist: PropTypes.bool,
  onDismiss: PropTypes.func
};

const Progress = ({
  className,
  children,
  value,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-progress", Object.assign({
    class: className
  }, rest, {
    value: value.toString()
  }));
};

Progress.propTypes = {
  value: PropTypes.number,
  className: PropTypes.string
};

const PILL_VARIANTS = {
  grey: 'hxEmphasisGray',
  purple: 'hxEmphasisPurple',
  subdued: 'hxSubdued'
};

const Status = ({
  className,
  children,
  variant,
  filled,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-status", Object.assign({
    class: classnames(className, PILL_VARIANTS[variant], {
      hxFill: filled
    })
  }, rest), children);
};

Status.propTypes = {
  variant: PropTypes.oneOf(Object.keys(PILL_VARIANTS)),
  filled: PropTypes.bool
};

const Popover = /*#__PURE__*/React.forwardRef(({
  onOpen,
  onClose,
  onReposition,
  className,
  open,
  children,
  relativeTo,
  ...rest
}, ref) => {
  const hxRef = useEventListener({
    onOpen,
    onClose,
    onReposition
  }, ref);
  return /*#__PURE__*/React.createElement("hx-popover", Object.assign({
    class: classnames(className),
    ref: hxRef,
    open: wcBool(open),
    "relative-to": relativeTo
  }, rest), children);
});
Popover.displayName = 'Popover';
Popover.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  id: PropTypes.string,
  position: PropTypes.oneOf(POSITIONS),
  relativeTo: PropTypes.string,
  open: PropTypes.bool,
  onClose: PropTypes.func,
  onOpen: PropTypes.func,
  onReposition: PropTypes.func
};

const Radio = /*#__PURE__*/React.forwardRef(({
  id,
  label,
  className,
  style,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement("hx-radio-control", {
    class: className,
    style: style,
    ref: ref
  }, /*#__PURE__*/React.createElement("input", Object.assign({}, rest, {
    id: id,
    type: "radio"
  })), /*#__PURE__*/React.createElement("label", {
    htmlFor: id
  }, /*#__PURE__*/React.createElement("hx-radio", null), label));
});
Radio.propTypes = {
  label: PropTypes.string.isRequired,
  className: PropTypes.string,
  style: PropTypes.object,
  checked: PropTypes.bool,
  id: PropTypes.string.isRequired,
  disabled: PropTypes.bool,
  required: PropTypes.bool,
  name: PropTypes.string,
  onChange: PropTypes.func
};
Radio.displayName = 'Radio';

const RadioSet = ({
  className,
  children,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-radio-set", Object.assign({
    class: className
  }, rest), children);
};

RadioSet.propTypes = {
  children: PropTypes.node
};

/**
 * Identical to React.useEffect, except that it never runs on mount. This is the equivalent of
 * the componentDidUpdate lifecycle function.
 * @see https://stackoverflow.com/questions/53253940/make-react-useeffect-hook-not-run-on-initial-render
 * @param {function:function} effect - A useEffect effect.
 * @param {array} dependencies - useEffect dependency list.
 */

const useEffectExceptOnMount = (effect, dependencies) => {
  const mounted = React.useRef(false);
  React.useEffect(() => {
    if (mounted.current) {
      const unmount = effect();
      return () => unmount && unmount();
    } else {
      mounted.current = true;
    }
  }, dependencies);
  React.useEffect(() => {
    return () => mounted.current = false;
  }, []);
};

/**
 * @see https://helixdesignsystem.github.io/helix-ui/components/search/
 */

const Search = /*#__PURE__*/React.forwardRef(({
  children,
  disabled,
  id,
  label,
  className,
  clearLabel,
  onClear,
  optional,
  required,
  containerId,
  value,
  style,
  ...rest
}, ref) => {
  /**
   * Show clear icon when value changes programmatically by triggering 'input' event manually.
   * @see https://stackoverflow.com/questions/23892547/what-is-the-best-way-to-trigger-onchange-event-in-react-js
   */
  const inputRef = useRef();
  useEffectExceptOnMount(() => {
    const input = inputRef.current;
    const nativeInputValueSetter = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value').set;
    nativeInputValueSetter.call(input, value);
    const ev = new Event('input', {
      bubbles: true
    });
    input.dispatchEvent(ev);
  }, [value]);
  return /*#__PURE__*/React.createElement("hx-search-control", {
    class: className,
    id: containerId,
    style: style,
    ref: ref
  }, /*#__PURE__*/React.createElement("input", Object.assign({
    id: id,
    value: value,
    ref: inputRef
  }, rest, {
    disabled: wcBool(disabled),
    type: "search"
  })), /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: "hxClear",
    "aria-label": clearLabel,
    hidden: true,
    onClick: onClear
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "times"
  })), /*#__PURE__*/React.createElement("hx-search", null), label && /*#__PURE__*/React.createElement("label", {
    className: classnames({
      hxOptional: optional,
      hxRequired: required
    }),
    htmlFor: id
  }, label));
});
Search.displayName = 'Search';
Search.propTypes = {
  className: PropTypes.string,
  style: PropTypes.object,
  clearLabel: PropTypes.string,
  label: PropTypes.string,
  id: PropTypes.string.isRequired,
  containerId: PropTypes.string,
  disabled: PropTypes.bool,
  onChange: PropTypes.func,
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
  onClear: PropTypes.func,
  optional: PropTypes.bool,
  required: PropTypes.bool
};
Search.defaultProps = {
  clearLabel: 'Clear search'
};

/**
 * @see https://helixdesignsystem.github.io/helix-ui/elements/hx-search-assistance/
 */

const SearchAssistance = ({
  children,
  className,
  relativeTo,
  ...rest
}) => {
  return /*#__PURE__*/React.createElement("hx-search-assistance", Object.assign({
    class: className,
    "relative-to": relativeTo
  }, rest), children);
};

SearchAssistance.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  relativeTo: PropTypes.string.isRequired,
  position: PropTypes.oneOf(POSITIONS)
};

var supportsPassiveEvents;
function arePassiveEventsSupported() {
  if (supportsPassiveEvents !== undefined) {
    return supportsPassiveEvents;
  }

  var passive = false;
  var options = {
    // @ts-ignore: this is a temporary object, it doesn't have to return anything
    get passive() {
      passive = true;
    }

  };

  var noop = function noop() {};

  window.addEventListener('t', noop, options);
  window.removeEventListener('t', noop, options);
  supportsPassiveEvents = passive;
  return passive;
}

var index =  useLayoutEffect ;

var useLatest = function useLatest(value) {
  var ref = useRef(value);
  index(function () {
    ref.current = value;
  });
  return ref;
};

var MOUSEDOWN = 'mousedown';
var TOUCHSTART = 'touchstart';
var events = [MOUSEDOWN, TOUCHSTART];

var getOptions = function getOptions(event) {
  if (event !== TOUCHSTART) {
    return;
  }

  if (arePassiveEventsSupported()) {
    return {
      passive: true
    };
  }
};

function useOnClickOutside(ref, handler) {

  var handlerRef = useLatest(handler);
  useEffect(function () {
    if (!handler) {
      return;
    }

    var listener = function listener(event) {
      if (!ref.current || !handlerRef.current || ref.current.contains(event.target)) {
        return;
      }

      handlerRef.current(event);
    };

    events.forEach(function (event) {
      document.addEventListener(event, listener, getOptions(event));
    });
    return function () {
      events.forEach(function (event) {
        document.removeEventListener(event, listener, getOptions(event));
      });
    };
  }, [!handler]);
}

/**
 * @see https://helixdesignsystem.github.io/helix-ui/components/search/
 */

const SearchAssist = ({
  children,
  onFocus,
  onBlur,
  position,
  ...rest
}) => {
  const [open, setOpen] = useState(false);
  const searchRef = useRef();
  useOnClickOutside(searchRef, () => setOpen(false));
  const hasChildren = React.Children.toArray(children).filter(c => c).length > 0;
  return /*#__PURE__*/React.createElement("div", {
    ref: searchRef
  }, /*#__PURE__*/React.createElement(Search, Object.assign({}, rest, {
    onFocus: e => {
      setOpen(true);
      onFocus && onFocus(e);
    },
    containerId: `${rest.id}-hx-search-control`
  })), hasChildren && /*#__PURE__*/React.createElement(SearchAssistance, {
    relativeTo: `${rest.id}-hx-search-control`,
    open: wcBool(open),
    position: position,
    onClick: () => setOpen(false)
  }, children));
};

SearchAssist.propTypes = {
  children: PropTypes.node.isRequired,
  position: PropTypes.oneOf(POSITIONS),
  className: PropTypes.string,
  clearLabel: PropTypes.string,
  label: PropTypes.string,
  id: PropTypes.string.isRequired,
  disabled: PropTypes.bool,
  onChange: PropTypes.func,
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
  onClear: PropTypes.func,
  optional: PropTypes.bool,
  required: PropTypes.bool
};

const Select = /*#__PURE__*/React.forwardRef(({
  children,
  className,
  disabled,
  id,
  label,
  onChange,
  optional,
  required,
  style,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement("hx-select-control", {
    class: className,
    style: style,
    ref: ref
  }, /*#__PURE__*/React.createElement("select", Object.assign({
    id: id,
    disabled: disabled,
    onChange: onChange,
    required: required
  }, rest), children), /*#__PURE__*/React.createElement("hx-select", null), label && /*#__PURE__*/React.createElement("label", {
    className: classnames({
      hxOptional: optional,
      hxRequired: required
    }),
    htmlFor: id
  }, label));
});
Select.displayName = 'Select';
Select.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  style: PropTypes.object,
  disabled: PropTypes.bool,
  id: PropTypes.string.isRequired,
  label: PropTypes.string,
  onChange: PropTypes.func.isRequired,
  optional: PropTypes.bool,
  required: PropTypes.bool
};

const Switch = /*#__PURE__*/React.forwardRef(({
  id,
  className,
  onLabel,
  offLabel,
  invalid,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement("hx-switch-control", {
    class: classnames('switch', className),
    ref: ref
  }, /*#__PURE__*/React.createElement("input", Object.assign({
    type: "checkbox",
    id: id
  }, rest, {
    invalid: invalid?.toString()
  })), /*#__PURE__*/React.createElement("label", {
    htmlFor: id
  }, /*#__PURE__*/React.createElement("hx-switch", {
    onlabel: onLabel,
    offlabel: offLabel,
    "aria-labelledby": id
  })));
});
Switch.propTypes = {
  id: PropTypes.string.isRequired,
  onLabel: PropTypes.string,
  offLabel: PropTypes.string,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  invalid: PropTypes.bool,
  label: PropTypes.bool,
  name: PropTypes.string,
  onChange: PropTypes.func
};
Switch.defaultProps = {
  onLabel: '',
  offLabel: ''
};
Switch.displayName = 'Switch';

const Text = /*#__PURE__*/React.forwardRef(({
  id,
  label,
  invalid,
  className,
  required,
  optional,
  children,
  prefix,
  suffix,
  style,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement("hx-text-control", {
    class: classnames(className, {
      hxInvalid: invalid
    }),
    style: style,
    ref: ref
  }, /*#__PURE__*/React.createElement("input", Object.assign({}, rest, {
    id: id,
    required: required,
    type: "text"
  })), label && /*#__PURE__*/React.createElement("label", {
    className: classnames({
      hxOptional: optional,
      hxRequired: required
    }),
    htmlFor: id
  }, label), prefix && /*#__PURE__*/React.createElement("span", {
    className: "hxPrefix"
  }, prefix), suffix && /*#__PURE__*/React.createElement("span", {
    className: "hxSuffix"
  }, suffix), children);
});
Text.displayName = 'Text';
Text.propTypes = {
  id: PropTypes.string.isRequired,
  className: PropTypes.string,
  style: PropTypes.object,
  children: PropTypes.node,
  optional: PropTypes.bool,
  disabled: PropTypes.bool,
  invalid: PropTypes.bool,
  required: PropTypes.bool,
  label: PropTypes.string,
  name: PropTypes.string,
  prefix: PropTypes.node,
  suffix: PropTypes.node,
  onChange: PropTypes.func
};

const TextArea = /*#__PURE__*/React.forwardRef(({
  id,
  label,
  className,
  required,
  disabled,
  optional,
  invalid,
  children,
  style,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement("hx-textarea-control", {
    class: classnames(className, {
      hxInvalid: invalid
    }),
    style: style,
    ref: ref
  }, /*#__PURE__*/React.createElement("textarea", Object.assign({}, rest, {
    id: id,
    required: required,
    disabled: disabled
  })), label && /*#__PURE__*/React.createElement("label", {
    className: classnames({
      hxOptional: optional,
      hxRequired: required
    }),
    htmlFor: id
  }, label), children);
});
TextArea.displayName = 'TextArea';
TextArea.propTypes = {
  id: PropTypes.string.isRequired,
  className: PropTypes.string,
  style: PropTypes.object,
  children: PropTypes.node,
  optional: PropTypes.bool,
  disabled: PropTypes.bool,
  required: PropTypes.bool,
  invalid: PropTypes.bool,
  label: PropTypes.bool,
  name: PropTypes.string,
  onChange: PropTypes.func
};

const Toast = /*#__PURE__*/React.forwardRef(({
  onOpen,
  onClose,
  className,
  children,
  onDismiss,
  onSubmit,
  ...rest
}, ref) => {
  const hxRef = useEventListener({
    onDismiss,
    onSubmit
  }, ref);
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("hx-toast", Object.assign({
    class: className,
    ref: hxRef
  }, rest), children));
});
Toast.displayName = 'Toast';
Toast.propTypes = {
  className: PropTypes.string,
  children: PropTypes.node.isRequired,
  type: PropTypes.oneOf(['info', 'error', 'success']),
  cta: PropTypes.string,
  onDismiss: PropTypes.func,
  onSubmit: PropTypes.func
};

const Tooltip = /*#__PURE__*/React.forwardRef(({
  children,
  id,
  position,
  onClose,
  onOpen,
  onReposition,
  ...rest
}, ref) => {
  const hxRef = useEventListener({
    onClose,
    onOpen,
    onReposition
  }, ref);
  return /*#__PURE__*/React.createElement("hx-tooltip", Object.assign({
    for: id,
    position: position,
    ref: hxRef
  }, rest), children);
});
Tooltip.displayName = 'Tooltip';
Tooltip.propTypes = {
  children: PropTypes.node.isRequired,
  id: PropTypes.string.isRequired,
  position: PropTypes.oneOf(POSITIONS),
  relativeTo: PropTypes.string,
  htmlFor: PropTypes.string
};
Tooltip.defaultProps = {
  position: 'top-left'
};

export { Alert, Breadcrumb, Busy, Button, Checkbox, ChoiceTile, Disclosure, Div, Drawer, Icon, Modal, Pill, Popover, Progress, Radio, RadioSet, Search, SearchAssist, Select, Status, Switch, Text, TextArea, Toast, Tooltip };
